# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_schedule_warehouse_hierarchy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n4v1/rules/delivery_schedule_warehouse_hierarchy.proto\x12?pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy\x1a\x11\x63ommon/base.proto"\xbf\x01\n"DeliveryScheduleWarehouseHierarchy\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1c\n\x14\x64\x65livery_schedule_id\x18\x02 \x01(\x05\x12\x1e\n\x16warehouse_hierarchy_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa7\x01\n/DeliveryScheduleWarehouseHierarchyCreateRequest\x12\x1c\n\x14\x64\x65livery_schedule_id\x18\x01 \x01(\x05\x12\x1e\n\x16warehouse_hierarchy_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x92\x02\n0DeliveryScheduleWarehouseHierarchyCreateResponse\x12\x92\x01\n%delivery_schedule_warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x63.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x03\n-DeliveryScheduleWarehouseHierarchyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcb\x02\n.DeliveryScheduleWarehouseHierarchyReadResponse\x12\x92\x01\n%delivery_schedule_warehouse_hierarchy\x18\x01 \x03(\x0b\x32\x63.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchy\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfe\x01\n/DeliveryScheduleWarehouseHierarchyUpdateRequest\x12\x92\x01\n%delivery_schedule_warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x63.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchy\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x92\x02\n0DeliveryScheduleWarehouseHierarchyUpdateResponse\x12\x92\x01\n%delivery_schedule_warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x63.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"u\n/DeliveryScheduleWarehouseHierarchyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"}\n0DeliveryScheduleWarehouseHierarchyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf5\x08\n)DeliveryScheduleWarehouseHierarchyService\x12\x91\x02\n(DeliveryScheduleWarehouseHierarchyCreate\x12p.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyCreateRequest\x1aq.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyCreateResponse"\x00\x12\x8b\x02\n&DeliveryScheduleWarehouseHierarchyRead\x12n.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyReadRequest\x1ao.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyReadResponse"\x00\x12\x91\x02\n(DeliveryScheduleWarehouseHierarchyUpdate\x12p.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyUpdateRequest\x1aq.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyUpdateResponse"\x00\x12\x91\x02\n(DeliveryScheduleWarehouseHierarchyDelete\x12p.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyDeleteRequest\x1aq.pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_schedule_warehouse_hierarchy_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHY"]._serialized_start = 141
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHY"]._serialized_end = 332
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_start = 335
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_end = 502
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_start = 505
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_end = 779
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYREADREQUEST"]._serialized_start = 782
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYREADREQUEST"]._serialized_end = 1177
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYREADRESPONSE"]._serialized_start = 1180
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYREADRESPONSE"]._serialized_end = 1511
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_start = 1514
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_end = 1768
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_start = 1771
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_end = 2045
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_start = 2047
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_end = 2164
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_start = 2166
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_end = 2291
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYSERVICE"]._serialized_start = 2294
    _globals["_DELIVERYSCHEDULEWAREHOUSEHIERARCHYSERVICE"]._serialized_end = 3435
# @@protoc_insertion_point(module_scope)
