# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_schedule_warehouse_hierarchy_pb2 as v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2,
)


class DeliveryScheduleWarehouseHierarchyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryScheduleWarehouseHierarchyCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyCreate",
            request_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateResponse.FromString,
        )
        self.DeliveryScheduleWarehouseHierarchyRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyRead",
            request_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadResponse.FromString,
        )
        self.DeliveryScheduleWarehouseHierarchyUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyUpdate",
            request_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateResponse.FromString,
        )
        self.DeliveryScheduleWarehouseHierarchyDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyDelete",
            request_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteResponse.FromString,
        )


class DeliveryScheduleWarehouseHierarchyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryScheduleWarehouseHierarchyCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleWarehouseHierarchyRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleWarehouseHierarchyUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryScheduleWarehouseHierarchyDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryScheduleWarehouseHierarchyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryScheduleWarehouseHierarchyCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleWarehouseHierarchyCreate,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateResponse.SerializeToString,
        ),
        "DeliveryScheduleWarehouseHierarchyRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleWarehouseHierarchyRead,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadResponse.SerializeToString,
        ),
        "DeliveryScheduleWarehouseHierarchyUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleWarehouseHierarchyUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateResponse.SerializeToString,
        ),
        "DeliveryScheduleWarehouseHierarchyDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryScheduleWarehouseHierarchyDelete,
            request_deserializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryScheduleWarehouseHierarchyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryScheduleWarehouseHierarchyCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyCreate",
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleWarehouseHierarchyRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyRead",
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleWarehouseHierarchyUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyUpdate",
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryScheduleWarehouseHierarchyDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_schedule_warehouse_hierarchy.DeliveryScheduleWarehouseHierarchyService/DeliveryScheduleWarehouseHierarchyDelete",
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__schedule__warehouse__hierarchy__pb2.DeliveryScheduleWarehouseHierarchyDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
