# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_warehouse_ref.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%v1/rules/delivery_warehouse_ref.proto\x12\x33pro.omni.oms.api.v1.rules.delivery_method_warehouse\x1a\x11\x63ommon/base.proto"\xa5\x01\n\x14\x44\x65liveryWarehouseRef\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x02 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x8d\x01\n!DeliveryWarehouseRefCreateRequest\x12\x1a\n\x12\x64\x65livery_method_id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n"DeliveryWarehouseRefCreateResponse\x12l\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32I.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRef\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfd\x02\n\x1f\x44\x65liveryWarehouseRefReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x96\x02\n DeliveryWarehouseRefReadResponse\x12l\n\x19\x64\x65livery_method_warehouse\x18\x01 \x03(\x0b\x32I.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRef\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xc9\x01\n!DeliveryWarehouseRefUpdateRequest\x12l\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32I.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRef\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n"DeliveryWarehouseRefUpdateResponse\x12l\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32I.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRef\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"g\n!DeliveryWarehouseRefDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"o\n"DeliveryWarehouseRefDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xdf\x06\n\x1b\x44\x65liveryWarehouseRefService\x12\xcf\x01\n\x1a\x44\x65liveryWarehouseRefCreate\x12V.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefCreateRequest\x1aW.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefCreateResponse"\x00\x12\xc9\x01\n\x18\x44\x65liveryWarehouseRefRead\x12T.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefReadRequest\x1aU.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefReadResponse"\x00\x12\xcf\x01\n\x1a\x44\x65liveryWarehouseRefUpdate\x12V.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefUpdateRequest\x1aW.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefUpdateResponse"\x00\x12\xcf\x01\n\x1a\x44\x65liveryWarehouseRefDelete\x12V.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefDeleteRequest\x1aW.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_warehouse_ref_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYWAREHOUSEREF"]._serialized_start = 114
    _globals["_DELIVERYWAREHOUSEREF"]._serialized_end = 279
    _globals["_DELIVERYWAREHOUSEREFCREATEREQUEST"]._serialized_start = 282
    _globals["_DELIVERYWAREHOUSEREFCREATEREQUEST"]._serialized_end = 423
    _globals["_DELIVERYWAREHOUSEREFCREATERESPONSE"]._serialized_start = 426
    _globals["_DELIVERYWAREHOUSEREFCREATERESPONSE"]._serialized_end = 647
    _globals["_DELIVERYWAREHOUSEREFREADREQUEST"]._serialized_start = 650
    _globals["_DELIVERYWAREHOUSEREFREADREQUEST"]._serialized_end = 1031
    _globals["_DELIVERYWAREHOUSEREFREADRESPONSE"]._serialized_start = 1034
    _globals["_DELIVERYWAREHOUSEREFREADRESPONSE"]._serialized_end = 1312
    _globals["_DELIVERYWAREHOUSEREFUPDATEREQUEST"]._serialized_start = 1315
    _globals["_DELIVERYWAREHOUSEREFUPDATEREQUEST"]._serialized_end = 1516
    _globals["_DELIVERYWAREHOUSEREFUPDATERESPONSE"]._serialized_start = 1519
    _globals["_DELIVERYWAREHOUSEREFUPDATERESPONSE"]._serialized_end = 1740
    _globals["_DELIVERYWAREHOUSEREFDELETEREQUEST"]._serialized_start = 1742
    _globals["_DELIVERYWAREHOUSEREFDELETEREQUEST"]._serialized_end = 1845
    _globals["_DELIVERYWAREHOUSEREFDELETERESPONSE"]._serialized_start = 1847
    _globals["_DELIVERYWAREHOUSEREFDELETERESPONSE"]._serialized_end = 1958
    _globals["_DELIVERYWAREHOUSEREFSERVICE"]._serialized_start = 1961
    _globals["_DELIVERYWAREHOUSEREFSERVICE"]._serialized_end = 2824
# @@protoc_insertion_point(module_scope)
