# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_warehouse_ref_pb2 as v1_dot_rules_dot_delivery__warehouse__ref__pb2


class DeliveryWarehouseRefServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryWarehouseRefCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefCreate",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateResponse.FromString,
        )
        self.DeliveryWarehouseRefRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefRead",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadResponse.FromString,
        )
        self.DeliveryWarehouseRefUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefUpdate",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateResponse.FromString,
        )
        self.DeliveryWarehouseRefDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefDelete",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteResponse.FromString,
        )


class DeliveryWarehouseRefServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryWarehouseRefCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseRefRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseRefUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseRefDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryWarehouseRefServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryWarehouseRefCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRefCreate,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateResponse.SerializeToString,
        ),
        "DeliveryWarehouseRefRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRefRead,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadResponse.SerializeToString,
        ),
        "DeliveryWarehouseRefUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRefUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateResponse.SerializeToString,
        ),
        "DeliveryWarehouseRefDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRefDelete,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryWarehouseRefService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryWarehouseRefCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefCreate",
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseRefRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefRead",
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseRefUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefUpdate",
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseRefDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryWarehouseRefService/DeliveryWarehouseRefDelete",
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__ref__pb2.DeliveryWarehouseRefDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
