# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/warehouse_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(v1/rules/warehouse_delivery_method.proto\x12\x33pro.omni.oms.api.v1.rules.warehouse_delivery_method\x1a\x11\x63ommon/base.proto"\xa8\x01\n\x17WarehouseDeliveryMethod\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x90\x01\n$WarehouseDeliveryMethodCreateRequest\x12\x14\n\x0cwarehouse_id\x18\x01 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n%WarehouseDeliveryMethodCreateResponse\x12o\n\x19warehouse_delivery_method\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x80\x03\n"WarehouseDeliveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9c\x02\n#WarehouseDeliveryMethodReadResponse\x12o\n\x19warehouse_delivery_method\x18\x01 \x03(\x0b\x32L.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xcf\x01\n$WarehouseDeliveryMethodUpdateRequest\x12o\n\x19warehouse_delivery_method\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n%WarehouseDeliveryMethodUpdateResponse\x12o\n\x19warehouse_delivery_method\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"j\n$WarehouseDeliveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"r\n%WarehouseDeliveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x86\x07\n\x1eWarehouseDeliveryMethodService\x12\xd8\x01\n\x1dWarehouseDeliveryMethodCreate\x12Y.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodCreateRequest\x1aZ.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodCreateResponse"\x00\x12\xd2\x01\n\x1bWarehouseDeliveryMethodRead\x12W.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodReadRequest\x1aX.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodReadResponse"\x00\x12\xd8\x01\n\x1dWarehouseDeliveryMethodUpdate\x12Y.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodUpdateRequest\x1aZ.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodUpdateResponse"\x00\x12\xd8\x01\n\x1dWarehouseDeliveryMethodDelete\x12Y.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodDeleteRequest\x1aZ.pro.omni.oms.api.v1.rules.warehouse_delivery_method.WarehouseDeliveryMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.warehouse_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSEDELIVERYMETHOD"]._serialized_start = 117
    _globals["_WAREHOUSEDELIVERYMETHOD"]._serialized_end = 285
    _globals["_WAREHOUSEDELIVERYMETHODCREATEREQUEST"]._serialized_start = 288
    _globals["_WAREHOUSEDELIVERYMETHODCREATEREQUEST"]._serialized_end = 432
    _globals["_WAREHOUSEDELIVERYMETHODCREATERESPONSE"]._serialized_start = 435
    _globals["_WAREHOUSEDELIVERYMETHODCREATERESPONSE"]._serialized_end = 662
    _globals["_WAREHOUSEDELIVERYMETHODREADREQUEST"]._serialized_start = 665
    _globals["_WAREHOUSEDELIVERYMETHODREADREQUEST"]._serialized_end = 1049
    _globals["_WAREHOUSEDELIVERYMETHODREADRESPONSE"]._serialized_start = 1052
    _globals["_WAREHOUSEDELIVERYMETHODREADRESPONSE"]._serialized_end = 1336
    _globals["_WAREHOUSEDELIVERYMETHODUPDATEREQUEST"]._serialized_start = 1339
    _globals["_WAREHOUSEDELIVERYMETHODUPDATEREQUEST"]._serialized_end = 1546
    _globals["_WAREHOUSEDELIVERYMETHODUPDATERESPONSE"]._serialized_start = 1549
    _globals["_WAREHOUSEDELIVERYMETHODUPDATERESPONSE"]._serialized_end = 1776
    _globals["_WAREHOUSEDELIVERYMETHODDELETEREQUEST"]._serialized_start = 1778
    _globals["_WAREHOUSEDELIVERYMETHODDELETEREQUEST"]._serialized_end = 1884
    _globals["_WAREHOUSEDELIVERYMETHODDELETERESPONSE"]._serialized_start = 1886
    _globals["_WAREHOUSEDELIVERYMETHODDELETERESPONSE"]._serialized_end = 2000
    _globals["_WAREHOUSEDELIVERYMETHODSERVICE"]._serialized_start = 2003
    _globals["_WAREHOUSEDELIVERYMETHODSERVICE"]._serialized_end = 2905
# @@protoc_insertion_point(module_scope)
