# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_category_category.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)v1/rules/delivery_category_category.proto\x12\x34pro.omni.oms.api.v1.rules.delivery_category_category\x1a\x11\x63ommon/base.proto"\xaa\x01\n\x18\x44\x65liveryCategoryCategory\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1c\n\x14\x64\x65livery_category_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x01\n%DeliveryCategoryCategoryCreateRequest\x12\x1c\n\x14\x64\x65livery_category_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63\x61tegory_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n&DeliveryCategoryCategoryCreateResponse\x12r\n\x1a\x64\x65livery_category_category\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategory\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x81\x03\n#DeliveryCategoryCategoryReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa2\x02\n$DeliveryCategoryCategoryReadResponse\x12t\n\x1c\x64\x65livery_category_categories\x18\x01 \x03(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategory\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xd3\x01\n%DeliveryCategoryCategoryUpdateRequest\x12r\n\x1a\x64\x65livery_category_category\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategory\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n&DeliveryCategoryCategoryUpdateResponse\x12r\n\x1a\x64\x65livery_category_category\x18\x01 \x01(\x0b\x32N.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategory\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"k\n%DeliveryCategoryCategoryDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"s\n&DeliveryCategoryCategoryDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x9b\x07\n\x1f\x44\x65liveryCategoryCategoryService\x12\xdd\x01\n\x1e\x44\x65liveryCategoryCategoryCreate\x12[.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryCreateRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryCreateResponse"\x00\x12\xd7\x01\n\x1c\x44\x65liveryCategoryCategoryRead\x12Y.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryReadRequest\x1aZ.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryReadResponse"\x00\x12\xdd\x01\n\x1e\x44\x65liveryCategoryCategoryUpdate\x12[.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryUpdateRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryUpdateResponse"\x00\x12\xdd\x01\n\x1e\x44\x65liveryCategoryCategoryDelete\x12[.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryDeleteRequest\x1a\\.pro.omni.oms.api.v1.rules.delivery_category_category.DeliveryCategoryCategoryDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_category_category_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYCATEGORYCATEGORY"]._serialized_start = 119
    _globals["_DELIVERYCATEGORYCATEGORY"]._serialized_end = 289
    _globals["_DELIVERYCATEGORYCATEGORYCREATEREQUEST"]._serialized_start = 292
    _globals["_DELIVERYCATEGORYCATEGORYCREATEREQUEST"]._serialized_end = 438
    _globals["_DELIVERYCATEGORYCATEGORYCREATERESPONSE"]._serialized_start = 441
    _globals["_DELIVERYCATEGORYCATEGORYCREATERESPONSE"]._serialized_end = 672
    _globals["_DELIVERYCATEGORYCATEGORYREADREQUEST"]._serialized_start = 675
    _globals["_DELIVERYCATEGORYCATEGORYREADREQUEST"]._serialized_end = 1060
    _globals["_DELIVERYCATEGORYCATEGORYREADRESPONSE"]._serialized_start = 1063
    _globals["_DELIVERYCATEGORYCATEGORYREADRESPONSE"]._serialized_end = 1353
    _globals["_DELIVERYCATEGORYCATEGORYUPDATEREQUEST"]._serialized_start = 1356
    _globals["_DELIVERYCATEGORYCATEGORYUPDATEREQUEST"]._serialized_end = 1567
    _globals["_DELIVERYCATEGORYCATEGORYUPDATERESPONSE"]._serialized_start = 1570
    _globals["_DELIVERYCATEGORYCATEGORYUPDATERESPONSE"]._serialized_end = 1801
    _globals["_DELIVERYCATEGORYCATEGORYDELETEREQUEST"]._serialized_start = 1803
    _globals["_DELIVERYCATEGORYCATEGORYDELETEREQUEST"]._serialized_end = 1910
    _globals["_DELIVERYCATEGORYCATEGORYDELETERESPONSE"]._serialized_start = 1912
    _globals["_DELIVERYCATEGORYCATEGORYDELETERESPONSE"]._serialized_end = 2027
    _globals["_DELIVERYCATEGORYCATEGORYSERVICE"]._serialized_start = 2030
    _globals["_DELIVERYCATEGORYCATEGORYSERVICE"]._serialized_end = 2953
# @@protoc_insertion_point(module_scope)
