# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_method_warehouse_hierarchy_pb2 as v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2,
)


class DeliveryMethodWarehouseHierarchyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryMethodWarehouseHierarchyCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService/DeliveryMethodWarehouseHierarchyCreate",
            request_serializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyCreateResponse.FromString,
        )
        self.DeliveryMethodWarehouseHierarchyRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService/DeliveryMethodWarehouseHierarchyRead",
            request_serializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyReadResponse.FromString,
        )
        self.DeliveryMethodWarehouseHierarchyUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService/DeliveryMethodWarehouseHierarchyUpdate",
            request_serializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyUpdateResponse.FromString,
        )
        self.DeliveryMethodWarehouseHierarchyDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService/DeliveryMethodWarehouseHierarchyDelete",
            request_serializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyDeleteResponse.FromString,
        )


class DeliveryMethodWarehouseHierarchyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryMethodWarehouseHierarchyCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodWarehouseHierarchyRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodWarehouseHierarchyUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodWarehouseHierarchyDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryMethodWarehouseHierarchyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryMethodWarehouseHierarchyCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodWarehouseHierarchyCreate,
            request_deserializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyCreateResponse.SerializeToString,
        ),
        "DeliveryMethodWarehouseHierarchyRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodWarehouseHierarchyRead,
            request_deserializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyReadResponse.SerializeToString,
        ),
        "DeliveryMethodWarehouseHierarchyUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodWarehouseHierarchyUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyUpdateResponse.SerializeToString,
        ),
        "DeliveryMethodWarehouseHierarchyDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodWarehouseHierarchyDelete,
            request_deserializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryMethodWarehouseHierarchyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryMethodWarehouseHierarchyCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService/DeliveryMethodWarehouseHierarchyCreate",
            v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodWarehouseHierarchyRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService/DeliveryMethodWarehouseHierarchyRead",
            v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodWarehouseHierarchyUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService/DeliveryMethodWarehouseHierarchyUpdate",
            v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodWarehouseHierarchyDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyService/DeliveryMethodWarehouseHierarchyDelete",
            v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__warehouse__hierarchy__pb2.DeliveryMethodWarehouseHierarchyDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
