# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_method_warehouse_hierarchy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n2v1/rules/delivery_method_warehouse_hierarchy.proto\x12=pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy\x1a\x11\x63ommon/base.proto"\xc5\x01\n DeliveryMethodWarehouseHierarchy\x12\n\n\x02id\x18\x01 \x01(\x05\x12$\n\x1c\x64\x65livery_method_warehouse_id\x18\x02 \x01(\x05\x12\x1e\n\x16warehouse_hierarchy_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xad\x01\n-DeliveryMethodWarehouseHierarchyCreateRequest\x12$\n\x1c\x64\x65livery_method_warehouse_id\x18\x01 \x01(\x05\x12\x1e\n\x16warehouse_hierarchy_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8a\x02\n.DeliveryMethodWarehouseHierarchyCreateResponse\x12\x8c\x01\n#delivery_method_warehouse_hierarchy\x18\x01 \x01(\x0b\x32_.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x89\x03\n+DeliveryMethodWarehouseHierarchyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc4\x02\n,DeliveryMethodWarehouseHierarchyReadResponse\x12\x8d\x01\n$delivery_method_warehouse_hierarchys\x18\x01 \x03(\x0b\x32_.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchy\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf6\x01\n-DeliveryMethodWarehouseHierarchyUpdateRequest\x12\x8c\x01\n#delivery_method_warehouse_hierarchy\x18\x01 \x01(\x0b\x32_.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchy\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8a\x02\n.DeliveryMethodWarehouseHierarchyUpdateResponse\x12\x8c\x01\n#delivery_method_warehouse_hierarchy\x18\x01 \x01(\x0b\x32_.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"s\n-DeliveryMethodWarehouseHierarchyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"{\n.DeliveryMethodWarehouseHierarchyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xcb\x08\n\'DeliveryMethodWarehouseHierarchyService\x12\x87\x02\n&DeliveryMethodWarehouseHierarchyCreate\x12l.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyCreateRequest\x1am.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyCreateResponse"\x00\x12\x81\x02\n$DeliveryMethodWarehouseHierarchyRead\x12j.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyReadRequest\x1ak.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyReadResponse"\x00\x12\x87\x02\n&DeliveryMethodWarehouseHierarchyUpdate\x12l.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyUpdateRequest\x1am.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyUpdateResponse"\x00\x12\x87\x02\n&DeliveryMethodWarehouseHierarchyDelete\x12l.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyDeleteRequest\x1am.pro.omni.oms.api.v1.rules.delivery_method_warehouse_hierarchy.DeliveryMethodWarehouseHierarchyDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_method_warehouse_hierarchy_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHY"]._serialized_start = 137
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHY"]._serialized_end = 334
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_start = 337
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_end = 510
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_start = 513
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_end = 779
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYREADREQUEST"]._serialized_start = 782
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYREADREQUEST"]._serialized_end = 1175
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYREADRESPONSE"]._serialized_start = 1178
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYREADRESPONSE"]._serialized_end = 1502
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_start = 1505
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_end = 1751
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_start = 1754
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_end = 2020
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_start = 2022
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_end = 2137
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_start = 2139
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_end = 2262
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYSERVICE"]._serialized_start = 2265
    _globals["_DELIVERYMETHODWAREHOUSEHIERARCHYSERVICE"]._serialized_end = 3364
# @@protoc_insertion_point(module_scope)
