# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_method_warehouse_pb2 as v1_dot_rules_dot_delivery__method__warehouse__pb2


class DeliveryMethodWarehouseServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryMethodWarehouseCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService/DeliveryMethodWarehouseCreate",
            request_serializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseCreateResponse.FromString,
        )
        self.DeliveryMethodWarehouseRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService/DeliveryMethodWarehouseRead",
            request_serializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseReadResponse.FromString,
        )
        self.DeliveryMethodWarehouseUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService/DeliveryMethodWarehouseUpdate",
            request_serializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseUpdateResponse.FromString,
        )
        self.DeliveryMethodWarehouseDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService/DeliveryMethodWarehouseDelete",
            request_serializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseDeleteResponse.FromString,
        )


class DeliveryMethodWarehouseServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryMethodWarehouseCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodWarehouseRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodWarehouseUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryMethodWarehouseDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryMethodWarehouseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryMethodWarehouseCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodWarehouseCreate,
            request_deserializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseCreateResponse.SerializeToString,
        ),
        "DeliveryMethodWarehouseRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodWarehouseRead,
            request_deserializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseReadResponse.SerializeToString,
        ),
        "DeliveryMethodWarehouseUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodWarehouseUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseUpdateResponse.SerializeToString,
        ),
        "DeliveryMethodWarehouseDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryMethodWarehouseDelete,
            request_deserializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryMethodWarehouseService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryMethodWarehouseCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService/DeliveryMethodWarehouseCreate",
            v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodWarehouseRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService/DeliveryMethodWarehouseRead",
            v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodWarehouseUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService/DeliveryMethodWarehouseUpdate",
            v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryMethodWarehouseDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseService/DeliveryMethodWarehouseDelete",
            v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__method__warehouse__pb2.DeliveryMethodWarehouseDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
