# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_method_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import warehouse_hierarchy_pb2 as v1_dot_rules_dot_warehouse__hierarchy__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(v1/rules/delivery_method_warehouse.proto\x12\x33pro.omni.oms.api.v1.rules.delivery_method_warehouse\x1a\x11\x63ommon/base.proto\x1a"v1/rules/warehouse_hierarchy.proto"\xc9\x02\n\x17\x44\x65liveryMethodWarehouse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12`\n\x1bhierarchi_warehouse_sort_by\x18\x03 \x01(\x0e\x32;.pro.omni.oms.api.v1.rules.delivery_method_warehouse.SortBy\x12\x61\n\x16transfer_warehouse_ids\x18\x04 \x03(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xee\x01\n$DeliveryMethodWarehouseCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1e\n\x16transfer_warehouse_ids\x18\x02 \x03(\t\x12`\n\x1bhierarchi_warehouse_sort_by\x18\x03 \x01(\x0e\x32;.pro.omni.oms.api.v1.rules.delivery_method_warehouse.SortBy\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n%DeliveryMethodWarehouseCreateResponse\x12o\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x80\x03\n"DeliveryMethodWarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9d\x02\n#DeliveryMethodWarehouseReadResponse\x12p\n\x1a\x64\x65livery_method_warehouses\x18\x01 \x03(\x0b\x32L.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouse\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xcf\x01\n$DeliveryMethodWarehouseUpdateRequest\x12o\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe3\x01\n%DeliveryMethodWarehouseUpdateResponse\x12o\n\x19\x64\x65livery_method_warehouse\x18\x01 \x01(\x0b\x32L.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"j\n$DeliveryMethodWarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"r\n%DeliveryMethodWarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard*\x1b\n\x06SortBy\x12\x07\n\x03\x41SC\x10\x00\x12\x08\n\x04\x44\x45SC\x10\x01\x32\x86\x07\n\x1e\x44\x65liveryMethodWarehouseService\x12\xd8\x01\n\x1d\x44\x65liveryMethodWarehouseCreate\x12Y.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseCreateRequest\x1aZ.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseCreateResponse"\x00\x12\xd2\x01\n\x1b\x44\x65liveryMethodWarehouseRead\x12W.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseReadRequest\x1aX.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseReadResponse"\x00\x12\xd8\x01\n\x1d\x44\x65liveryMethodWarehouseUpdate\x12Y.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseUpdateRequest\x1aZ.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseUpdateResponse"\x00\x12\xd8\x01\n\x1d\x44\x65liveryMethodWarehouseDelete\x12Y.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseDeleteRequest\x1aZ.pro.omni.oms.api.v1.rules.delivery_method_warehouse.DeliveryMethodWarehouseDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_method_warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SORTBY"]._serialized_start = 2294
    _globals["_SORTBY"]._serialized_end = 2321
    _globals["_DELIVERYMETHODWAREHOUSE"]._serialized_start = 153
    _globals["_DELIVERYMETHODWAREHOUSE"]._serialized_end = 482
    _globals["_DELIVERYMETHODWAREHOUSECREATEREQUEST"]._serialized_start = 485
    _globals["_DELIVERYMETHODWAREHOUSECREATEREQUEST"]._serialized_end = 723
    _globals["_DELIVERYMETHODWAREHOUSECREATERESPONSE"]._serialized_start = 726
    _globals["_DELIVERYMETHODWAREHOUSECREATERESPONSE"]._serialized_end = 953
    _globals["_DELIVERYMETHODWAREHOUSEREADREQUEST"]._serialized_start = 956
    _globals["_DELIVERYMETHODWAREHOUSEREADREQUEST"]._serialized_end = 1340
    _globals["_DELIVERYMETHODWAREHOUSEREADRESPONSE"]._serialized_start = 1343
    _globals["_DELIVERYMETHODWAREHOUSEREADRESPONSE"]._serialized_end = 1628
    _globals["_DELIVERYMETHODWAREHOUSEUPDATEREQUEST"]._serialized_start = 1631
    _globals["_DELIVERYMETHODWAREHOUSEUPDATEREQUEST"]._serialized_end = 1838
    _globals["_DELIVERYMETHODWAREHOUSEUPDATERESPONSE"]._serialized_start = 1841
    _globals["_DELIVERYMETHODWAREHOUSEUPDATERESPONSE"]._serialized_end = 2068
    _globals["_DELIVERYMETHODWAREHOUSEDELETEREQUEST"]._serialized_start = 2070
    _globals["_DELIVERYMETHODWAREHOUSEDELETEREQUEST"]._serialized_end = 2176
    _globals["_DELIVERYMETHODWAREHOUSEDELETERESPONSE"]._serialized_start = 2178
    _globals["_DELIVERYMETHODWAREHOUSEDELETERESPONSE"]._serialized_end = 2292
    _globals["_DELIVERYMETHODWAREHOUSESERVICE"]._serialized_start = 2324
    _globals["_DELIVERYMETHODWAREHOUSESERVICE"]._serialized_end = 3226
# @@protoc_insertion_point(module_scope)
